@@ -24,14 +24,16 @@ if [ "`uname -r`" = "$STOCKVERSION" ];
 	if [ -f $SYMLINK ];
 		then rm $SYMLINK
 	fi
+	echo "Detected stock kernel, creating symlinks..."
 	ln -s $MODDIR/omap1/psfreedom.ko $SYMLINK
 fi
 
-if [ "`uname -r`" = "$POWERVERSION" ] || [ "`uname -r`" = "$NEOPWNVERSION" ];
+if [ "`uname -r`" = "$POWERVERSION" ] || [ "`uname -r`" = "$NEOPWNVERSION" ]  || [ "`uname -r`" = "2.6.28.10power37" ];
 	then
 	if [ -f $SYMLINK ];
 		then rm $SYMLINK
 	fi
+	echo "Detected kernel-power, creating symlinks..."
 	ln -s $MODDIR/power40/psfreedom.ko $SYMLINK
 fi
 }
