@@ -21,11 +21,18 @@ class CompatibilityWindow : public QMainWindow
 public:
     explicit CompatibilityWindow(QWidget *parent = 0);
     ~CompatibilityWindow();
+public slots:
+
 
 private:
     Ui::CompatibilityWindow *ui;
     QWebView *view;
     QWebViewSelectionSuppressor *suppressor;
+
+private slots:
+    void setButtonIcons();
+    void zoomIn();
+    void zoomOut();
 };
 
 #endif // COMPATIBILITYWINDOW_H
