@@ -6,13 +6,16 @@ KernelMessagesWindow::KernelMessagesWindow(QWidget *parent) :
     ui(new Ui::KernelMessagesWindow)
 {
     ui->setupUi(this);
-    QMainWindow::setCentralWidget(ui->textBrowser);
     connect(ui->actionExport, SIGNAL(triggered()), this, SLOT(exportlogs()));
 #ifdef Q_WS_MAEMO_5
     setAttribute(Qt::WA_Maemo5StackedWindow);
+//    ui->textBrowser->setStyleSheet(QString::fromUtf8("background-color: rgb(255, 255, 255);"));
+//    ui->textBrowser->setTextColor(QColor("red"));
 #endif
+    this->showLogs();
+    QMainWindow::setCentralWidget(ui->verticalLayoutWidget);
 //    QRect screenGeometry = QApplication::desktop()->screenGeometry();
-
+//    ui->textBrowser->setStyleSheet(QString::fromUtf8("background-color: rgb(255, 255, 255);"));
 }
 
 KernelMessagesWindow::~KernelMessagesWindow()
@@ -24,11 +27,10 @@ KernelMessagesWindow::~KernelMessagesWindow()
 void KernelMessagesWindow::showLogs()
 {
     system("touch ~/.tempdmesg");
-#ifdef Q_WS_X11
-    system("dmesg | sed 's/$/\\<br\\>/' > ~/.tempdmesg");
-#endif
 #ifdef Q_WS_MAEMO_5
     system("dmesg | grep PSFreedom* | sed 's/$/\\<br\\>/' > ~/.tempdmesg");
+#else
+    system("dmesg | sed 's/$/\\<br\\>/' > ~/.tempdmesg");
 #endif
     ui->textBrowser->setSource(QUrl("file:///home/user/.tempdmesg"));
 }
