@@ -7,6 +7,7 @@
 #include <QTextStream>
 #ifdef Q_WS_MAEMO_5
 #include <QMaemo5InformationBox>
+#include <QPalette>
 #endif
 
 namespace Ui {
@@ -21,6 +22,7 @@ public:
     explicit KernelMessagesWindow(QWidget *parent = 0);
     ~KernelMessagesWindow();
     Ui::KernelMessagesWindow *ui;
+    QPalette *widget;
 
 public slots:
     void showLogs();
