@@ -10,6 +10,7 @@
 #include <kernelmessageswindow.h>
 #include <procwatch.h>
 #include <helpwindow.h>
+#include <QPainter>
 #ifdef Q_WS_MAEMO_5
 #include <QMaemo5InformationBox>
 #endif
@@ -25,10 +26,14 @@ class MainWindow : public QMainWindow
 public:
     explicit MainWindow(QWidget *parent = 0);
     ~MainWindow();
+public slots:
+    void setBackgroundImage(const QString &image);
 
 private:
     Ui::MainWindow *ui;
     void connectSignals();
+    QString m_BackgroundImage;
+    void paintEvent(QPaintEvent*);
 
 private slots:
     void about();
